import logging
import requests

logger = logging.getLogger(__file__)

# usage example:
#
# with TMSSsession('paulus', 'pauluspass') as session:
#    response = session.get(url='http://localhost:8008/api/task_draft/')
#    print(response)


class TMSSsession(object):

    def __init__(self, username, password, host):
        self.session = requests.session()
        self.username = username
        self.password = password
        self.host = host

    def __enter__(self):
        self.session.__enter__()
        self.session.verify = False

        # get authentication page of OIDC through TMSS redirect
        response = self.session.get(self.host + '/oidc/authenticate/', allow_redirects=True)
        csrftoken = self.session.cookies['csrftoken']

        # post user credentials to login page, also pass csrf token
        data = {'username': self.username, 'password': self.password, 'csrfmiddlewaretoken': csrftoken}
        response = self.session.post(url=response.url, data=data, allow_redirects=True)

        # raise when sth went wrong
        if "The username and/or password you specified are not correct" in response.content.decode('utf8'):
            raise ValueError("The username and/or password you specified are not correct")
        if response.status_code != 200:
            raise ConnectionError(response.content.decode('utf8'))

        # return the authenticated session as user context
        return self.session

    def __exit__(self, type, value, traceback):
        try:
            # logout user
            self.session.get(self.host + '/api/logout/', allow_redirects=True)
            self.session.__exit__(self, type, value, traceback)
        except:
            pass

